@@ -65,8 +65,8 @@ class SearchInternal(RequestHandler, ComponentHandler):
                 self.resultComponents.append(self._getPlaylistComponent(element))
             if shelfElementKey in element.keys() and findVideos:
                 for shelfElement in self._getShelfComponent(element)['elements']:
-                    self.resultComponents.append(self._getVideoComponent(shelfElement, shelfTitle = self.getShelfComponent(element)['title']))
-            if richItemKey in element.keys():
+                    self.resultComponents.append(self._getVideoComponent(shelfElement, shelfTitle = self._getShelfComponent(element)['title']))
+            if richItemKey in element.keys() and findVideos:
                 richItemElement = self._getValue(element, [richItemKey, 'content'])
                 ''' Initial fallback handling for VideosSearch '''
                 if videoElementKey in richItemElement.keys():
